@@ -39,6 +39,13 @@
 #define GEIER_ERROR_SCHEMA_VALIDATE_DOC  (GEIER_ERROR_BASE+4)
 #define GEIER_ERROR_FIND_NODE_NO_UNIQUE_NODE  (GEIER_ERROR_BASE+5)
 
+#ifndef __attribute__
+/* This feature is available in gcc versions 2.5 and later.  */
+# if __cplusplus == 1 || __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
+#  define __attribute__(Spec)  /* empty */
+# endif
+#endif
+
 /**
  * geier_context:
  *
@@ -308,6 +315,7 @@ int geier_xml_to_text(geier_context *context,
  * geier_xml_to_encoded_text
  * @context: a #geier_context.
  * @input: the XML document that should be converted
+ * @encoding: the encoding to possibly convert the XML document to.
  * @output: pointer to where the document should be written to (as a C string)
  * @outlen: the length of the buffer @output points to.
  *
@@ -501,15 +509,38 @@ char *geier_get_clearing_error_text(geier_context *context,
  * certificate, that is automatically extracted from the PKCS&num;12 file with
  * the provided filename.  The @pincode is used to decrypt the container.
  *
+ * @Deprecated: This funtion has been renamed since 0.8.  Please use
+ * #geier_dsig_sign_softpse, which has exactly the same signature.
+ *
  * Returns: %0 on success, %1 on error.  The signed document is written to
  * @output.
  */
 int geier_dsig_sign(geier_context *context,
 		    const xmlDoc *input, xmlDoc **output,
-		    const char *softpse_filename, const char *pincode);
+		    const char *softpse_filename, const char *pincode)
+	__attribute__((deprecated));
 
 /**
- * geier_dsig_sign_text
+ * geier_dsig_sign_softpse
+ * @context: a #geier_context.
+ * @input: the XML document that should be signed.
+ * @output: pointer to where the signed XML document should be written to.
+ * @softpse_filename: name of the PKCS&num;12 container file.
+ * @pincode: the pincode.
+ *
+ * Sign the provided Elster-XML document (supplied as @input) with the software
+ * certificate, that is automatically extracted from the PKCS&num;12 file with
+ * the provided filename.  The @pincode is used to decrypt the container.
+ *
+ * Returns: %0 on success, %1 on error.  The signed document is written to
+ * @output.
+ */
+int geier_dsig_sign_softpse(geier_context *context,
+			    const xmlDoc *input, xmlDoc **output,
+			    const char *softpse_filename, const char *pincode);
+
+/**
+ * geier_dsig_sign_softpse_text
  * @context: a #geier_context.
  * @input: the XML document that should be signed, supplied as a C string.
  * @inlen: the length of @input.
@@ -526,10 +557,86 @@ int geier_dsig_sign(geier_context *context,
  * Returns: %0 on success, %1 on error.  The signed document is written to
  * @output, the length of @output is stored to @outlen on success.
  */
+int geier_dsig_sign_softpse_text(geier_context *context,
+				 const unsigned char *input, size_t inlen,
+				 unsigned char **output, size_t *outlen,
+				 const char *softpse_filename,
+				 const char *pincode);
+
+/**
+ * geier_dsig_sign_text
+ * @context: a #geier_context.
+ * @input: the XML document that should be signed, supplied as a C string.
+ * @inlen: the length of @input.
+ * @output: pointer to where the resulting XML document should be written to
+ * (as a C string)
+ * @outlen: the length of the buffer @output points to.
+ * @softpse_filename: name of the PKCS&num;12 container file.
+ * @pincode: the pincode.
+ *
+ * Sign the provided Elster-XML document (supplied as @input) with the software
+ * certificate, that is automatically extracted from the PKCS&num;12 file with
+ * the provided filename.  The @pincode is used to decrypt the container.
+ *
+ * @Deprecated: This funtion has been renamed since 0.8.  Please use
+ * #geier_dsig_sign_softpse_text, which has exactly the same signature.
+ *
+ * Returns: %0 on success, %1 on error.  The signed document is written to
+ * @output, the length of @output is stored to @outlen on success.
+ */
 int geier_dsig_sign_text(geier_context *context,
 			 const unsigned char *input, size_t inlen,
 			 unsigned char **output, size_t *outlen,
-			 const char *softpse_filename, const char *pincode);
+			 const char *softpse_filename,
+			 const char *pincode)
+	__attribute__((deprecated));
+
+
+
+/**
+ * geier_dsig_sign_opensc
+ * @context: a #geier_context.
+ * @input: the XML document that should be signed.
+ * @output: pointer to where the signed XML document should be written to.
+ * @cert_id: the certificate id to use.
+ *
+ * Sign the provided Elster-XML document (supplied as @input) using a
+ * smartcard.  You need to specify the ID of the certificate to use for
+ * signing as @cert_id, as it is returned by pkcs15-tool.
+ *
+ * This function is only available in OpenSSL-based libgeier versions.
+ *
+ * Returns: %0 on success, %1 on error.  The signed document is written to
+ * @output.
+ */
+int geier_dsig_sign_opensc(geier_context *context,
+			   const xmlDoc *input, xmlDoc **output,
+			   unsigned int cert_id);
+
+/**
+ * geier_dsig_sign_opensc_text
+ * @context: a #geier_context.
+ * @input: the XML document that should be signed, supplied as a C string.
+ * @inlen: the length of @input.
+ * @output: pointer to where the resulting XML document should be written to
+ * (as a C string)
+ * @outlen: the length of the buffer @output points to.
+ * @cert_id: the certificate id to use.
+ *
+ * Sign the provided Elster-XML document (supplied as @input) using a
+ * smartcard.  You need to specify the ID of the certificate to use for
+ * signing as @cert_id, as it is returned by pkcs15-tool.
+ *
+ * This function is only available in OpenSSL-based libgeier versions.
+ *
+ * Returns: %0 on success, %1 on error.  The signed document is written to
+ * @output, the length of @output is stored to @outlen on success.
+ */
+int geier_dsig_sign_opensc_text(geier_context *context,
+				const unsigned char *input, size_t inlen,
+				unsigned char **output, size_t *outlen,
+				unsigned int cert_id);
+
 
 GEIER_END_PROTOS
 
